@@ -1,6 +1,6 @@
 package MARC::Charset;
 
-our $VERSION = '0.9';
+our $VERSION = '0.92';
 use strict;
 use warnings;
 
@@ -78,6 +78,13 @@ sub marc8_to_utf8
     my $combining = '';
     CHAR_LOOP: while ($index < $length) 
     {
+        # spaces just get added on unmolested
+        if (substr($marc8, $index, 1) eq ' ')
+        {
+            $utf8 .= ' ';
+            $index += 1;
+            next CHAR_LOOP;
+        }
 
         # look for any escape sequences
         my $new_index = _process_escape(\$marc8, $index, $length);
@@ -124,7 +131,8 @@ sub marc8_to_utf8
         if (!$found)
         {
             warn("no mapping found at position $index in $marc8 ".
-                "g0=".charset_name($G0) . " g1=".charset_name($G1));
+                "g0=".MARC::Charset::Constants::charset_name($G0) . " " .
+                "g1=".MARC::Charset::Constants::charset_name($G1));
             if (!$ignore_errors)
             {
                 reset_charsets();
@@ -168,8 +176,17 @@ sub utf8_to_marc8
     my $marc8 = '';
     for (my $i=0; $i<$len; $i++)
     {
+        my $slice = substr($utf8, $i, 1);
+
+        # spaces are copied from utf8 into marc8
+        if ($slice eq ' ')
+        {
+            $marc8 .= ' ';
+            next;
+        }
+        
         # try to find the code point in our mapping table 
-        my $code = $table->lookup_by_utf8(substr($utf8, $i, 1));
+        my $code = $table->lookup_by_utf8($slice);
 
         if (! $code)
         {
